This dataset (i.e., MERS_2013_MEregion) contains 55 observations of final outbreak size generated by given numbers of seed cases,
which were collected in Middle East respiratory syndrome (MERS) outbreaks in the Middle East (ME) regions in 2013.
MERS_2013_MEregionA data frame (data.frame) with 55 rows of records, and 3 columns of variables:
obs.seedObservations of the number of seed cases that generated the outbreak.
obs.finalsizeObservations of final outbreak size generated by given numbers (given in obs.seed) of seed cases.
typeA categorical variable takes the value "outbreaksize" indicating the type of observations.
Poletto C, Pelat C, Levy-Bruhl D, Yazdanpanah Y, Boelle PY, Colizza V. Assessment of the Middle East respiratory syndrome coronavirus (MERS-CoV) epidemic in the Middle East and risk of international spread using a novel maximum likelihood analysis approach. Eurosurveillance. 2014;19(23):20824. tools:::Rd_expr_doi("10.2807/1560-7917.ES2014.19.23.20824"), see the "baseline" column in Table 1 for the raw data.
Kucharski AJ, Althaus CL. The role of superspreading in Middle East respiratory syndrome coronavirus (MERS-CoV) transmission. Eurosurveillance. 2015;20(25):21167. tools:::Rd_expr_doi("10.2807/1560-7917.ES2015.20.25.21167")
data(MERS_2013_MEregion)
summary(MERS_2013_MEregion)
Run the code above in your browser using DataLab